@@ -34,10 +34,12 @@ class MemcachedCacheBackendConfig(BaseModel):
 
 
 class MemcachedCacheBackend(CacheBackendProtocol):
+    """Memcached-based cache backend."""
+
     _client: Client
 
     def __init__(self, config: MemcachedCacheBackendConfig) -> None:
-        """This class offers a cache backend based on memcached.
+        """Initialize `MemcachedCacheBackend`.
 
         Args:
             config: required configuration to connect to memcached.
@@ -52,7 +54,7 @@ class MemcachedCacheBackend(CacheBackendProtocol):
         return self._client
 
     async def get(self, key: str) -> Any:  # pylint: disable=invalid-overridden-method
-        """Retrieves a value from cache corresponding to the given key.
+        """Retrieve a value from cache corresponding to the given key.
 
         Args:
             key: name of cached value.
@@ -65,8 +67,7 @@ class MemcachedCacheBackend(CacheBackendProtocol):
         return self._config.deserialize(value)
 
     async def set(self, key: str, value: Any, expiration: int) -> None:  # pylint: disable=invalid-overridden-method
-        """Set sa value in cache for a given key for a duration determined by
-        expiration.
+        """Set sa value in cache for a given key for a duration determined by expiration.
 
         Args:
             key: key to cache `value` under.
@@ -88,7 +89,7 @@ class MemcachedCacheBackend(CacheBackendProtocol):
         )
 
     async def delete(self, key: str) -> None:  # pylint: disable=invalid-overridden-method
-        """Deletes a value from the cache and removes the given key.
+        """Delete a value from the cache and remove the given key.
 
         Args:
             key: key to be deleted from the cache.
