@@ -13,6 +13,7 @@ from typing import (
     Iterable,
     Iterator,
     List,
+    Literal,
     Optional,
     TypeVar,
     Union,
@@ -21,7 +22,6 @@ from typing import (
 
 from pydantic import BaseConfig, FilePath, validator
 from pydantic.generics import GenericModel
-from typing_extensions import Literal
 
 from starlite.datastructures import ETag
 from starlite.datastructures.background_tasks import BackgroundTask, BackgroundTasks
@@ -47,14 +47,15 @@ R = TypeVar("R")
 
 
 class ResponseContainer(ABC, GenericModel, Generic[R]):
+    """Generic response container."""
+
     class Config(BaseConfig):
         arbitrary_types_allowed = True
 
     background: Optional[Union[BackgroundTask, BackgroundTasks]] = None
-    """
-        A [BackgroundTask][starlite.datastructures.BackgroundTask] instance or
-        [BackgroundTasks][starlite.datastructures.BackgroundTasks] to execute after the response is finished.
-        Defaults to None.
+    """A [BackgroundTask][starlite.datastructures.BackgroundTask] instance or
+    [BackgroundTasks][starlite.datastructures.BackgroundTasks] to execute after the response is finished.
+    Defaults to None.
     """
     headers: Dict[str, Any] = {}
     """A string/string dictionary of response headers. Header keys are insensitive. Defaults to None."""
@@ -100,7 +101,7 @@ class File(ResponseContainer[FileResponse]):
     """An optional result of calling 'os.stat'. If not provided, this will be done by the response constructor."""
     chunk_size: int = ONE_MEGA_BYTE
     """The size of chunks to use when streaming the file"""
-    content_disposition_type: "Literal['attachment', 'inline']" = "attachment"
+    content_disposition_type: Literal["attachment", "inline"] = "attachment"
     """The type of the 'Content-Disposition'. Either 'inline' or 'attachment'."""
     etag: Optional[ETag] = None
     """
@@ -140,7 +141,7 @@ class File(ResponseContainer[FileResponse]):
     def validate_file_system(  # pylint: disable=no-self-argument
         cls, value: "FileSystemProtocol"
     ) -> "FileSystemProtocol":
-        """Ensures the value is a file system spec.
+        """Ensure the value is a file system spec.
 
         Args:
             value: A file system spec.
@@ -160,7 +161,7 @@ class File(ResponseContainer[FileResponse]):
         app: "Starlite",
         request: "Request",
     ) -> FileResponse:
-        """Creates a FileResponse instance.
+        """Create a FileResponse instance.
 
         Args:
             headers: A dictionary of headers.
@@ -201,11 +202,11 @@ class Redirect(ResponseContainer[RedirectResponse]):
         # TODO: update the redirect response to support HTML as well.
         #   This argument is currently ignored.
         media_type: Union["MediaType", str],
-        status_code: "Literal[301, 302, 303, 307, 308]",
+        status_code: Literal[301, 302, 303, 307, 308],
         app: "Starlite",
         request: "Request",
     ) -> RedirectResponse:
-        """Creates a RedirectResponse instance.
+        """Create a RedirectResponse instance.
 
         Args:
             headers: A dictionary of headers.
@@ -237,8 +238,7 @@ class Stream(ResponseContainer[StreamingResponse]):
         cls,
         value: Union[StreamType[Union[str, bytes]], Callable[[], StreamType[Union[str, bytes]]]],
     ) -> StreamType[Union[str, bytes]]:
-        """Set the iterator value by ensuring that the return value is
-        iterable.
+        """Set the iterator value by ensuring that the return value is iterable.
 
         Args:
             value: An iterable or callable returning an iterable.
@@ -256,7 +256,7 @@ class Stream(ResponseContainer[StreamingResponse]):
         app: "Starlite",
         request: "Request",
     ) -> StreamingResponse:
-        """Creates a StreamingResponse instance.
+        """Create a StreamingResponse instance.
 
         Args:
             headers: A dictionary of headers.
@@ -295,7 +295,7 @@ class Template(ResponseContainer["TemplateResponse"]):
         app: "Starlite",
         request: "Request",
     ) -> "TemplateResponse":
-        """Creates a TemplateResponse instance.
+        """Create a TemplateResponse instance.
 
         Args:
             headers: A dictionary of headers.
@@ -325,12 +325,13 @@ class Template(ResponseContainer["TemplateResponse"]):
         )
 
     def create_template_context(self, request: "Request") -> Dict[str, Any]:
-        """Creates a context object for the template.
+        """Create a context object for the template.
 
         Args:
             request: A [Request][starlite.connection.request.Request] instance.
 
         Returns:
+            A dictionary holding the template context
         """
         csrf_token = request.scope.get("_csrf_token", "")
         return {
