@@ -9,9 +9,11 @@ if TYPE_CHECKING:
 
 
 class UploadFile(MultipartUploadFile):
+    """Representation of a file upload, modifying the pydantic schema."""
+
     @classmethod
     def __modify_schema__(cls, field_schema: Dict[str, Any], field: Optional["ModelField"]) -> None:
-        """Creates a pydantic JSON schema.
+        """Create a pydantic JSON schema.
 
         Args:
             field_schema: The schema being generated for the field.
