@@ -5,11 +5,13 @@ from starlite.status_codes import WS_1000_NORMAL_CLOSURE
 
 
 class WebSocketException(StarLiteException):
+    """Exception class for websocket related events."""
+
     code: int
     """Exception code. Should be a number in the 4000+ range."""
 
     def __init__(self, *args: Any, detail: str, code: int = 4500) -> None:
-        """Exception class for websocket related events.
+        """Initialize `WebSocketException`.
 
         Args:
             *args: Any exception args.
@@ -21,8 +23,10 @@ class WebSocketException(StarLiteException):
 
 
 class WebSocketDisconnect(WebSocketException):
+    """Exception class for websocket disconnect events."""
+
     def __init__(self, *args: Any, detail: str, code: int = WS_1000_NORMAL_CLOSURE) -> None:
-        """Exception class for websocket disconnect events.
+        """Initialize `WebSocketDisconnect`.
 
         Args:
             *args: Any exception args.
