@@ -8,9 +8,10 @@ from starlite.logging.utils import resolve_handlers
 
 
 class QueueListenerHandler(QueueHandler):
+    """Configure queue listener and handler to support non-blocking logging configuration."""
+
     def __init__(self, handlers: Optional[List[Any]] = None) -> None:
-        """Configures queue listener and handler to support non-blocking
-        logging configuration.
+        """Initialize `?QueueListenerHandler`.
 
         Args:
             handlers: Optional 'ConvertingList'
