@@ -1,12 +1,14 @@
-import re
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Any, List, Optional, Pattern, Union
+from typing import TYPE_CHECKING, Any, List, Optional, Union
 
 from pydantic import BaseConfig, BaseModel
 
 from starlite.connection import ASGIConnection
 from starlite.enums import ScopeType
-from starlite.middleware.utils import should_bypass_middleware
+from starlite.middleware.utils import (
+    build_exclude_path_pattern,
+    should_bypass_middleware,
+)
 
 if TYPE_CHECKING:
 
@@ -14,7 +16,7 @@ if TYPE_CHECKING:
 
 
 class AuthenticationResult(BaseModel):
-    """This pydantic model is a container for authentication data."""
+    """Pydantic model for authentication data."""
 
     user: Any
     """
@@ -30,6 +32,10 @@ class AuthenticationResult(BaseModel):
 
 
 class AbstractAuthenticationMiddleware(ABC):
+    """Abstract AuthenticationMiddleware that allows users to create their own AuthenticationMiddleware by extending it
+    and overriding the 'authenticate_request' method.
+    """
+
     scopes: "Scopes" = {ScopeType.HTTP, ScopeType.WEBSOCKET}
     """
     Scopes supported by the middleware.
@@ -41,9 +47,7 @@ class AbstractAuthenticationMiddleware(ABC):
         exclude: Optional[Union[str, List[str]]] = None,
         exclude_from_auth_key: str = "exclude_from_auth",
     ) -> None:
-        """This is an abstract AuthenticationMiddleware that allows users to
-        create their own AuthenticationMiddleware by extending it and
-        overriding the 'authenticate_request' method.
+        """Initialize `AbstractAuthenticationMiddleware`.
 
         Args:
             app: An ASGIApp, this value is the next ASGI handler to call in the middleware stack.
@@ -51,14 +55,12 @@ class AbstractAuthenticationMiddleware(ABC):
             exclude_from_auth_key: An identifier to use on routes to disable authentication for a particular route.
         """
         self.app = app
-        self.exclude: Optional[Pattern[str]] = None
         self.exclude_from_auth_key = exclude_from_auth_key
-
-        if exclude:
-            self.exclude = re.compile("|".join(exclude)) if isinstance(exclude, list) else re.compile(exclude)
+        self.exclude = build_exclude_path_pattern(exclude=exclude)
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
-        """
+        """ASGI callable.
+
         Args:
             scope: The ASGI connection scope.
             receive: The ASGI receive function.
@@ -80,8 +82,10 @@ class AbstractAuthenticationMiddleware(ABC):
 
     @abstractmethod
     async def authenticate_request(self, connection: ASGIConnection) -> AuthenticationResult:  # pragma: no cover
-        """This method must be overridden by subclasses. It receives the http
-        connection and returns an instance of.
+        """Receive the http connection and return an `AuthenticationResult`.
+
+        Notes:
+            - This method must be overridden by subclasses.
 
         Args:
             connection: An [ASGIConnection][starlite.connection.ASGIConnection] instance.
