@@ -53,8 +53,7 @@ class SessionModel(SessionModelMixin):
 
 
 def create_session_model(base: Type[Any], table_name: str = "session") -> Type[SessionModelMixin]:
-    """Dynamically generate a session storage model and register it with the
-    declarative base.
+    """Dynamically generate a session storage model and register it with the declarative base.
 
     Args:
         base: SQLAlchemy declarative base
@@ -72,8 +71,7 @@ def create_session_model(base: Type[Any], table_name: str = "session") -> Type[S
 
 
 def register_session_model(base: Union[registry, Any], model: Type[SessionModelT]) -> Type[SessionModelT]:
-    """Map and register a pre-existing model subclassing `SessionModelMixin`
-    with a declarative base or registry.
+    """Map and register a pre-existing model subclassing `SessionModelMixin` with a declarative base or registry.
 
     Args:
         base: Either a `orm.registry` or `DeclarativeBase`
@@ -87,15 +85,20 @@ def register_session_model(base: Union[registry, Any], model: Type[SessionModelT
 
 
 class BaseSQLAlchemyBackend(Generic[AnySASessionT], ServerSideBackend["SQLAlchemyBackendConfig"], ABC):
+    """Session backend to store data in a database with SQLAlchemy. Works with both sync and async engines.
+
+    Notes:
+        - Requires `sqlalchemy` which needs to be installed separately, and a configured
+        [SQLAlchemyPlugin][starlite.plugins.sql_alchemy.SQLAlchemyPlugin].
+    """
+
     __slots__ = ("_model", "_session_maker")
 
     def __init__(self, config: "SQLAlchemyBackendConfig") -> None:
-        """Session backend to store data in a database with SQLAlchemy. Works
-        with both sync and async engines.
+        """Initialize `BaseSQLAlchemyBackend`.
 
-        Notes:
-            - Requires `sqlalchemy` which needs to be installed separately, and a configured
-            [SQLAlchemyPlugin][starlite.plugins.sql_alchemy.SQLAlchemyPlugin].
+        Args:
+            config: An instance of `SQLAlchemyBackendConfig`
         """
         super().__init__(config=config)
         self._model = config.model
@@ -116,6 +119,8 @@ class BaseSQLAlchemyBackend(Generic[AnySASessionT], ServerSideBackend["SQLAlchem
 
 
 class AsyncSQLAlchemyBackend(BaseSQLAlchemyBackend[AsyncSASession]):
+    """Asynchronous SQLAlchemy backend."""
+
     async def _get_session_obj(self, *, sa_session: AsyncSASession, session_id: str) -> Optional[SessionModelMixin]:
         result = await sa_session.scalars(self._select_session_obj(session_id))
         return result.one_or_none()
@@ -132,7 +137,7 @@ class AsyncSQLAlchemyBackend(BaseSQLAlchemyBackend[AsyncSASession]):
         async with self._create_sa_session() as sa_session:
             session_obj = await self._get_session_obj(sa_session=sa_session, session_id=session_id)
             if session_obj:
-                if not session_obj.expired:
+                if not session_obj.expired:  # type: ignore[truthy-function]
                     self._update_session_expiry(session_obj)  # type: ignore[unreachable]
                     await sa_session.commit()
                     return session_obj.data
@@ -164,8 +169,7 @@ class AsyncSQLAlchemyBackend(BaseSQLAlchemyBackend[AsyncSASession]):
             await sa_session.commit()
 
     async def delete(self, session_id: str) -> None:
-        """Delete the data associated with `session_id`. Fails silently if no
-        such session-ID exists.
+        """Delete the data associated with `session_id`. Fails silently if no such session-ID exists.
 
         Args:
             session_id: The session-ID
@@ -198,6 +202,8 @@ class AsyncSQLAlchemyBackend(BaseSQLAlchemyBackend[AsyncSASession]):
 
 
 class SQLAlchemyBackend(BaseSQLAlchemyBackend[SASession]):
+    """Synchronous SQLAlchemy backend."""
+
     def _get_session_obj(self, *, sa_session: SASession, session_id: str) -> Optional[SessionModelMixin]:
         return sa_session.scalars(self._select_session_obj(session_id)).one_or_none()
 
@@ -206,7 +212,7 @@ class SQLAlchemyBackend(BaseSQLAlchemyBackend[SASession]):
         session_obj = self._get_session_obj(sa_session=sa_session, session_id=session_id)
 
         if session_obj:
-            if not session_obj.expired:
+            if not session_obj.expired:  # type: ignore[truthy-function]
                 self._update_session_expiry(session_obj)  # type: ignore[unreachable]
                 sa_session.commit()
                 return session_obj.data
@@ -257,8 +263,7 @@ class SQLAlchemyBackend(BaseSQLAlchemyBackend[SASession]):
         sa_session.commit()
 
     async def delete(self, session_id: str) -> None:
-        """Delete the data associated with `session_id`. Fails silently if no
-        such session-ID exists.
+        """Delete the data associated with `session_id`. Fails silently if no such session-ID exists.
 
         Args:
             session_id: The session-ID
@@ -296,6 +301,8 @@ class SQLAlchemyBackend(BaseSQLAlchemyBackend[SASession]):
 
 
 class SQLAlchemyBackendConfig(ServerSideSessionConfig):
+    """Configuration for `SQLAlchemyBackend` and `AsyncSQLAlchemyBackend`"""
+
     model: Type[SessionModelMixin]
     plugin: SQLAlchemyPlugin
 
@@ -308,8 +315,9 @@ class SQLAlchemyBackendConfig(ServerSideSessionConfig):
 
     @property
     def _backend_class(self) -> Type[Union[SQLAlchemyBackend, AsyncSQLAlchemyBackend]]:  # type: ignore[override]
-        """Return either `SQLAlchemyBackend` or `AsyncSQLAlchemyBackend`,
-        depending on the engine type configured in the `SQLAlchemyPlugin`"""
+        """Return either `SQLAlchemyBackend` or `AsyncSQLAlchemyBackend`, depending on the engine type configured in the
+        `SQLAlchemyPlugin`
+        """
         if cast("SQLAlchemyPluginConfig", self.plugin._config).use_async_engine:  # pylint: disable=protected-access
             return AsyncSQLAlchemyBackend
         return SQLAlchemyBackend
