@@ -6,13 +6,15 @@ from typing import (
     List,
     NamedTuple,
     Optional,
+    Protocol,
     Tuple,
     Type,
     TypeVar,
     Union,
+    runtime_checkable,
 )
 
-from typing_extensions import Protocol, TypeGuard, get_args, runtime_checkable
+from typing_extensions import TypeGuard, get_args
 
 if TYPE_CHECKING:
     from pydantic import BaseModel
@@ -24,11 +26,13 @@ ModelT = TypeVar("ModelT")
 
 @runtime_checkable
 class PluginProtocol(Protocol[ModelT]):  # pragma: no cover
+    """Base plugin protocol to be inherited when implementing plugins."""
+
     __slots__ = ()
 
     def on_app_init(self, app: "Starlite") -> None:
-        """Receives the Starlite application instance before `init` is
-        finalized and allows the plugin to update various attributes.
+        """Receive the Starlite application instance before `init` is finalized and allow the plugin to update various
+        attributes.
 
         Examples:
             ```python
@@ -73,8 +77,7 @@ class PluginProtocol(Protocol[ModelT]):  # pragma: no cover
 
     @staticmethod
     def is_plugin_supported_type(value: Any) -> TypeGuard[ModelT]:
-        """Given a value of indeterminate type, determine if this value is
-        supported by the plugin.
+        """Given a value of indeterminate type, determine if this value is supported by the plugin.
 
         Args:
             value: An arbitrary value.
@@ -85,8 +88,7 @@ class PluginProtocol(Protocol[ModelT]):  # pragma: no cover
         return False
 
     def to_pydantic_model_class(self, model_class: Type[ModelT], **kwargs: Any) -> Type["BaseModel"]:
-        """Given a model_class supported by the plugin, convert it to a
-        subclass of the pydantic BaseModel.
+        """Given a model_class supported by the plugin, convert it to a subclass of the pydantic BaseModel.
 
         Args:
             model_class: A model class supported by the plugin.
@@ -98,9 +100,8 @@ class PluginProtocol(Protocol[ModelT]):  # pragma: no cover
         raise NotImplementedError()
 
     def from_pydantic_model_instance(self, model_class: Type[ModelT], pydantic_model_instance: "BaseModel") -> ModelT:
-        """Given an instance of a pydantic model created using a plugin's
-        'to_pydantic_model_class', return an instance of the class from which
-        that pydantic model has been created.
+        """Given an instance of a pydantic model created using a plugin's 'to_pydantic_model_class', return an instance
+        of the class from which that pydantic model has been created.
 
         This class is passed in as the 'model_class' kwarg.
 
@@ -114,8 +115,7 @@ class PluginProtocol(Protocol[ModelT]):  # pragma: no cover
         raise NotImplementedError()
 
     def to_dict(self, model_instance: ModelT) -> Union[Dict[str, Any], Awaitable[Dict[str, Any]]]:
-        """Given an instance of a model supported by the plugin, return a
-        dictionary of serializable values.
+        """Given an instance of a model supported by the plugin, return a dictionary of serializable values.
 
         Args:
             model_instance: A model instance of the type supported by the plugin.
@@ -129,8 +129,7 @@ class PluginProtocol(Protocol[ModelT]):  # pragma: no cover
         raise NotImplementedError()
 
     def from_dict(self, model_class: Type[ModelT], **kwargs: Any) -> ModelT:
-        """Given a class supported by this plugin and a dict of values, create
-        an instance of the class.
+        """Given a class supported by this plugin and a dict of values, create an instance of the class.
 
         Args:
             model_class: A model class supported by the plugin.
@@ -143,8 +142,7 @@ class PluginProtocol(Protocol[ModelT]):  # pragma: no cover
 
 
 def get_plugin_for_value(value: Any, plugins: List[PluginProtocol]) -> Optional[PluginProtocol]:
-    """Helper function to return a plugin for handling the given value, if any
-    plugin supports it.
+    """Return a plugin for handling the given value, if any plugin supports it.
 
     Args:
         value: An arbitrary value.
@@ -165,14 +163,15 @@ def get_plugin_for_value(value: Any, plugins: List[PluginProtocol]) -> Optional[
 
 
 class PluginMapping(NamedTuple):
+    """Named tuple, mapping plugins > models."""
+
     plugin: PluginProtocol
     model_class: Any
 
     def get_model_instance_for_value(
         self, value: Union["BaseModel", List["BaseModel"], Tuple["BaseModel", ...]]
     ) -> Any:
-        """Given a value generated by plugin, return an instance of the
-        original class.
+        """Given a value generated by plugin, return an instance of the original class.
 
         Can also accept a list or tuple of values.
 
