@@ -1,6 +1,13 @@
-from typing import TYPE_CHECKING, Any, Dict, Optional, Type, Union
-
-from typing_extensions import Protocol, runtime_checkable
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Optional,
+    Protocol,
+    Type,
+    Union,
+    runtime_checkable,
+)
 
 if TYPE_CHECKING:
     from sqlalchemy.engine import Connection, Engine
@@ -14,6 +21,8 @@ SQLAlchemyBinaryType = Union["BINARY", "VARBINARY", "LargeBinary"]
 
 @runtime_checkable
 class SessionMakerTypeProtocol(Protocol):
+    """Protocol for a sessionmaker."""
+
     def __init__(
         self,
         bind: "Optional[Union[AsyncEngine, Engine, Connection]]",
@@ -23,13 +32,18 @@ class SessionMakerTypeProtocol(Protocol):
         info: Dict[Any, Any],
         **kwargs: Any,
     ) -> None:
+        """Initialize the sessionmaker."""
         ...
 
     def __call__(self) -> "Union[Session, AsyncSession]":
+        """Return a session instance."""
         ...
 
 
 @runtime_checkable
 class SessionMakerInstanceProtocol(Protocol):
+    """Protocol for a sessionmaker instance."""
+
     def __call__(self) -> "Union[Session, AsyncSession]":
+        """Return a session instance."""
         ...
